==> payara-embedded-all-5.2021.4-sources.jar: com/sun/enterprise/connectors/ConnectionManagerFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.connectors;

import com.sun.appserv.connectors.internal.api.ConnectorRuntimeException;
import com.sun.logging.LogDomains;
import org.glassfish.resourcebase.resources.api.PoolInfo;
import org.glassfish.resourcebase.resources.api.ResourceInfo;

import javax.resource.spi.ConnectionManager;
import java.util.logging.Level;
import java.util.logging.Logger;

/* Authors : Binod P G, Aditya Gore
 *
 */
public class ConnectionManagerFactory {

    public static ConnectionManager getAvailableConnectionManager(
            PoolInfo poolInfo, boolean forceNoLazyAssoc, ResourceInfo resourceInfo)
            throws ConnectorRuntimeException {

        ConnectorRegistry registry = ConnectorRegistry.getInstance();
        PoolMetaData pmd = registry.getPoolMetaData(poolInfo);
        boolean isLazyEnlist = pmd.isLazyEnlistable();
        boolean isLazyAssoc = pmd.isLazyAssociatable();

        ConnectionManagerImpl mgr = null;

        if (isLazyAssoc && !forceNoLazyAssoc) {
            logFine("Creating LazyAssociatableConnectionManager");
            mgr = new LazyAssociatableConnectionManagerImpl(poolInfo, resourceInfo);
        }else if (isLazyEnlist) {
            logFine("Creating LazyEnlistableConnectionManager");
            mgr = new LazyEnlistableConnectionManagerImpl(poolInfo, resourceInfo);
        } else {
            logFine("Creating plain ConnectionManager");
            mgr = new ConnectionManagerImpl(poolInfo, resourceInfo);
        }
        return mgr;
    }

    private static void logFine(String message) {
        Logger _logger = LogDomains.getLogger(ConnectionManagerFactory.class, LogDomains.RSR_LOGGER);
        if (_logger.isLoggable(Level.FINE)) {
            _logger.fine(message);
        }
    }
}

==> payara-embedded-all-6.2023.9-sources.jar: com/sun/enterprise/connectors/ConnectionManagerFactory.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.connectors;

import com.sun.appserv.connectors.internal.api.ConnectorRuntimeException;
import com.sun.logging.LogDomains;
import org.glassfish.resourcebase.resources.api.PoolInfo;
import org.glassfish.resourcebase.resources.api.ResourceInfo;

import jakarta.resource.spi.ConnectionManager;
import java.util.logging.Level;
import java.util.logging.Logger;

/* Authors : Binod P G, Aditya Gore
 *
 */
public class ConnectionManagerFactory {

    public static ConnectionManager getAvailableConnectionManager(
            PoolInfo poolInfo, boolean forceNoLazyAssoc, ResourceInfo resourceInfo)
            throws ConnectorRuntimeException {

        ConnectorRegistry registry = ConnectorRegistry.getInstance();
        PoolMetaData pmd = registry.getPoolMetaData(poolInfo);
        boolean isLazyEnlist = pmd.isLazyEnlistable();
        boolean isLazyAssoc = pmd.isLazyAssociatable();

        ConnectionManagerImpl mgr = null;

        if (isLazyAssoc && !forceNoLazyAssoc) {
            logFine("Creating LazyAssociatableConnectionManager");
            mgr = new LazyAssociatableConnectionManagerImpl(poolInfo, resourceInfo);
        }else if (isLazyEnlist) {
            logFine("Creating LazyEnlistableConnectionManager");
            mgr = new LazyEnlistableConnectionManagerImpl(poolInfo, resourceInfo);
        } else {
            logFine("Creating plain ConnectionManager");
            mgr = new ConnectionManagerImpl(poolInfo, resourceInfo);
        }
        return mgr;
    }

    private static void logFine(String message) {
        Logger _logger = LogDomains.getLogger(ConnectionManagerFactory.class, LogDomains.RSR_LOGGER);
        if (_logger.isLoggable(Level.FINE)) {
            _logger.fine(message);
        }
    }
}
